import { Component, ElementRef, ViewChild } from '@angular/core';
import { Data } from '@angular/router';
import { Chart, registerables } from 'chart.js';
import { DataProviderService } from '../data-provider.service';
import { providerData } from 'src/models/temp.model';
import { Observable } from 'rxjs';

@Component({
  selector: 'app-home',
  templateUrl: 'home.page.html',
  styleUrls: ['home.page.scss'],
})
export class HomePage {
  // Importing ViewChild. We need @ViewChild decorator to get a reference to the local variable 
  // that we have added to the canvas element in the HTML template.
  @ViewChild('barCanvas', { static: true }) private barCanvas: ElementRef;
  @ViewChild('doughnutCanvas', { static: true }) private doughnutCanvas: ElementRef;
  @ViewChild('lineCanvas', { static: true }) private lineCanvas: ElementRef;

  //data = null;
  barChart: any;
  doughnutChart: any;
  lineChart: any;
  showData = [];
  a$: Observable<providerData>;
  
  constructor(private myDataProvider: DataProviderService) {
    Chart.register(...registerables);
  }
  // getallData(){
  //   this.data$=this.myDataProvider.allData();
  // }
  // When we try to call our chart to initialize methods in ngOnInit() it shows an error nativeElement of undefined. 
  // So, we need to call all chart methods in ngAfterViewInit() where @ViewChild and @ViewChildren will be resolved.
  ionViewDidEnter() {
    this.barChartMethod();
    this.doughnutChartMethod();
    this.lineChartMethod();
    this.func();
    //this.data=this.myDataProvider.getData(this.showData,this.lineChart);
  }

  func(){
    this.a$ = this.myDataProvider.insert(null,null,null,null)
    console.log(this.a$)
  }
  
  barChartMethod() {
    // Now we need to supply a Chart element reference with an object that defines the type of chart we want to use, and the type of data we want to display.
    //var data;
    //console.log(this.myDataProvider.getData(this.showData,this.lineChart))
    var that = this
    this.myDataProvider.getData(null, null).subscribe(data => {
      var dataJSON: Array<Object>
      dataJSON = JSON.parse(data.toString())
      var x = []
      var y = []
      for (var i = 0; i < dataJSON.length; i++) {
        var frame = dataJSON[i];
        y.push(frame['all'])
        x.push(frame['iden'])
      };
      //console.log(x)
      //console.log(y)
      this.barChart = new Chart(this.barCanvas.nativeElement, {
        type: 'bar',
        data: {
          labels: x,
          datasets: [{
            label: '# of Votes',
            data: y,
            backgroundColor: [
              'rgba(255, 99, 132, 0.2)',
              'rgba(54, 162, 235, 0.2)',
              'rgba(255, 206, 86, 0.2)',
              'rgba(75, 192, 192, 0.2)',
              'rgba(153, 102, 255, 0.2)',
              'rgba(255, 159, 64, 0.2)'
            ],
            borderColor: [
              'rgba(255,99,132,1)',
              'rgba(54, 162, 235, 1)',
              'rgba(255, 206, 86, 1)',
              'rgba(75, 192, 192, 1)',
              'rgba(153, 102, 255, 1)',
              'rgba(255, 159, 64, 1)'
            ],
            borderWidth: 1
          }]
        },
        options: {

        }
      });
    });
  }

  doughnutChartMethod() {
    var that = this

    this.myDataProvider.getData(null, null).subscribe(data => {
      var dataJSON: Array<Object>
      dataJSON = JSON.parse(data.toString())
      var camera = 0
      var kTCCServicePhotosAdd = 0
      var location = 0
      var mediaLibrary = 0
      var microphone = 0
      var photos = 0
      for (var i = 0; i < dataJSON.length; i++) {
        var frame = dataJSON[i];
        camera += frame['camera']
        kTCCServicePhotosAdd += frame['kTCCServicePhotosAdd'];
        location += frame['location']
        mediaLibrary += frame['mediaLibrary']
        microphone += frame['microphone']
        photos += frame['photos']
      };
      var dataval = [camera, kTCCServicePhotosAdd, location, mediaLibrary, microphone, photos]

      this.doughnutChart = new Chart(this.doughnutCanvas.nativeElement, {
        type: 'doughnut',
        data: {
          labels: ['cam', 'PhotosAdd', 'gps', 'media', 'mic', 'photos'],
          datasets: [{
            label: '# of Votes',
            data: dataval,
            backgroundColor: [
              'rgba(255, 159, 64, 0.2)',
              'rgba(255, 99, 132, 0.2)',
              'rgba(54, 162, 235, 0.2)',
              'rgba(255, 206, 86, 0.2)',
              'rgba(75, 192, 192, 0.2)'
            ],
            hoverBackgroundColor: [
              '#FFCE56',
              '#FF6384',
              '#36A2EB',
              '#FFCE56',
              '#FF6384'
            ]
          }]
        }
      });
    });

  }

  lineChartMethod() {
    var that = this
    var dataSet

    this.lineChart = new Chart(this.lineCanvas.nativeElement, {
      type: 'line',
      data: {
        labels: ['January', 'February', 'March', 'April'],
        datasets: [
          {
            label: 'Sell per week',
            fill: false,

            backgroundColor: 'rgba(75,192,192,0.4)',
            borderColor: 'rgba(75,192,192,1)',
            borderCapStyle: 'butt',
            borderDash: [],
            borderDashOffset: 0.0,
            borderJoinStyle: 'miter',
            pointBorderColor: 'rgba(75,192,192,1)',
            pointBackgroundColor: '#fff',
            pointBorderWidth: 1,
            pointHoverRadius: 5,
            pointHoverBackgroundColor: 'rgba(75,192,192,1)',
            pointHoverBorderColor: 'rgba(220,220,220,1)',
            pointHoverBorderWidth: 2,
            pointRadius: 1,
            pointHitRadius: 10,
            data: this.showData,
            spanGaps: false,
          }
        ]
      }
    });
  }
}